@@ -36,11 +36,13 @@ from ..core.util import stream_parameters, isfinite
 from ..element import Table, Graph, Contours
 from ..streams import Stream, RangeXY, RangeX, RangeY
 from ..util.transform import dim
-from .util import (get_dynamic_mode, initialize_unbounded, dim_axis_label,
-                   attach_streams, traverse_setter, get_nested_streams,
-                   compute_overlayable_zorders, get_nested_plot_frame,
-                   split_dmap_overlay, get_axis_padding, get_range,
-                   get_minimum_span, get_plot_frame, scale_fontsize)
+from .util import (
+    get_dynamic_mode, initialize_unbounded, dim_axis_label,
+    attach_streams, traverse_setter, get_nested_streams,
+    compute_overlayable_zorders, get_nested_plot_frame,
+    split_dmap_overlay, get_axis_padding, get_range, get_minimum_span,
+    get_plot_frame, scale_fontsize, dynamic_update
+)
 
 
 class Plot(param.Parameterized):
@@ -688,6 +690,41 @@ class DimensionedPlot(Plot):
         # Iterate over all elements in a normalization group
         # and accumulate their ranges into the supplied dictionary.
         elements = [el for el in elements if el is not None]
+        data_ranges = {}
+        categorical_dims = []
+        for el in elements:
+            for el_dim in el.dimensions('ranges'):
+                if hasattr(el, 'interface'):
+                    if isinstance(el, Graph) and el_dim in el.nodes.dimensions():
+                        dtype = el.nodes.interface.dtype(el.nodes, el_dim)
+                    elif isinstance(el, Contours) and el.level is not None:
+                        dtype = np.array([el.level]).dtype # Remove when deprecating level
+                    else:
+                        dtype = el.interface.dtype(el, el_dim)
+                elif hasattr(el, '__len__') and len(el):
+                    dtype = el.dimension_values(el_dim).dtype
+                else:
+                    dtype = None
+
+                if all(util.isfinite(r) for r in el_dim.range):
+                    data_range = (None, None)
+                elif dtype is not None and dtype.kind in 'SU':
+                    data_range = ('', '')
+                elif isinstance(el, Graph) and el_dim in el.kdims[:2]:
+                    data_range = el.nodes.range(2, dimension_range=False)
+                elif el_dim.values:
+                    ds = Dataset(el_dim.values, el_dim)
+                    data_range = ds.range(el_dim, dimension_range=False)
+                else:
+                    data_range = el.range(el_dim, dimension_range=False)
+
+                data_ranges[(el, el_dim)] = data_range
+
+                if (any(isinstance(r, util.basestring) for r in data_range) or
+                    (el_dim.type is not None and issubclass(el_dim.type, util.basestring)) or
+                    (dtype is not None and dtype.kind in 'SU')):
+                    categorical_dims.append(el_dim)
+
         prev_ranges = ranges.get(group, {})
         group_ranges = OrderedDict()
         for el in elements:
@@ -710,6 +747,8 @@ class DimensionedPlot(Plot):
                         drange = values.min(), values.max()
                     elif util.isscalar(values):
                         drange = values, values
+                    elif values.dtype.kind in 'US':
+                        factors = util.unique_array(values)
                     elif len(values) == 0:
                         drange = np.NaN, np.NaN
                     else:
@@ -721,7 +760,7 @@ class DimensionedPlot(Plot):
                             factors = util.unique_array(values)
                     if dim_name not in group_ranges:
                         group_ranges[dim_name] = {'data': [], 'hard': [], 'soft': []}
-    
+
                     if factors is not None:
                         if 'factors' not in group_ranges[dim_name]:
                             group_ranges[dim_name]['factors'] = []
@@ -734,35 +773,13 @@ class DimensionedPlot(Plot):
                 dim_name = el_dim.name
                 if dim_name in prev_ranges and not framewise:
                     continue
-                if hasattr(el, 'interface'):
-                    if isinstance(el, Graph) and el_dim in el.nodes.dimensions():
-                        dtype = el.nodes.interface.dtype(el.nodes, el_dim)
-                    elif isinstance(el, Contours) and el.level is not None:
-                        dtype = np.array([el.level]).dtype # Remove when deprecating level
-                    else:
-                        dtype = el.interface.dtype(el, el_dim)
-                else:
-                    dtype = None
-
-                if all(util.isfinite(r) for r in el_dim.range):
-                    data_range = (None, None)
-                elif dtype is not None and dtype.kind in 'SU':
-                    data_range = ('', '')
-                elif isinstance(el, Graph) and el_dim in el.kdims[:2]:
-                    data_range = el.nodes.range(2, dimension_range=False)
-                elif el_dim.values:
-                    ds = Dataset(el_dim.values, el_dim)
-                    data_range = ds.range(el_dim, dimension_range=False)
-                else:
-                    data_range = el.range(el_dim, dimension_range=False)
-
+                data_range = data_ranges[(el, el_dim)]
                 if dim_name not in group_ranges:
                     group_ranges[dim_name] = {'data': [], 'hard': [], 'soft': []}
                 group_ranges[dim_name]['data'].append(data_range)
                 group_ranges[dim_name]['hard'].append(el_dim.range)
                 group_ranges[dim_name]['soft'].append(el_dim.soft_range)
-                if (any(isinstance(r, util.basestring) for r in data_range) or
-                    el_dim.type is not None and issubclass(el_dim.type, util.basestring)):
+                if el_dim in categorical_dims:
                     if 'factors' not in group_ranges[dim_name]:
                         group_ranges[dim_name]['factors'] = []
                     if el_dim.values not in ([], None):
@@ -777,7 +794,7 @@ class DimensionedPlot(Plot):
                         values = el.nodes.dimension_values(el_dim, expanded=False)
                     if (isinstance(values, np.ndarray) and values.dtype.kind == 'O' and
                         all(isinstance(v, (np.ndarray)) for v in values)):
-                        values = np.concatenate(values)
+                        values = np.concatenate(values) if len(values) else []
                     factors = util.unique_array(values)
                     group_ranges[dim_name]['factors'].append(factors)
 
@@ -804,8 +821,17 @@ class DimensionedPlot(Plot):
             dranges = {'data': data_range, 'hard': hard_range,
                        'soft': soft_range, 'combined': combined}
             if 'factors' in values:
-                dranges['factors'] = util.unique_array([
-                    v for fctrs in values['factors'] for v in fctrs])
+                all_factors = values['factors']
+                factor_dtypes = {fs.dtype for fs in all_factors} if all_factors else []
+                dtype = list(factor_dtypes)[0] if len(factor_dtypes) == 1 else None
+                expanded = [v for fctrs in all_factors for v in fctrs]
+                if dtype is not None:
+                    try:
+                        # Try to keep the same dtype
+                        expanded = np.array(expanded, dtype=dtype)
+                    except Exception:
+                        pass
+                dranges['factors'] = util.unique_array(expanded)
             dim_ranges.append((gdim, dranges))
         if prev_ranges and not (framewise and top_level):
             for d, dranges in dim_ranges:
@@ -1630,6 +1656,27 @@ class GenericOverlayPlot(GenericElementPlot):
         return plottype(obj, **plotopts)
 
 
+    def _match_subplot(self, key, subplot, items, element):
+        found = False
+        temp_items = list(items)
+        while not found:
+            idx, spec, exact = dynamic_update(self, subplot, key, element, temp_items)
+            if idx is not None:
+                if not exact:
+                    exact_matches = [
+                        dynamic_update(self, subplot, k, element, temp_items)
+                        for k in self.subplots
+                    ]
+                    exact_matches = [m for m in exact_matches if m[-1]]
+                    if exact_matches:
+                        idx = exact_matches[0][0]
+                        _, el = temp_items.pop(idx)
+                        continue
+            found = True
+        if idx is not None:
+            idx = items.index(temp_items.pop(idx))
+        return idx, spec, exact
+
     def _create_dynamic_subplots(self, key, items, ranges, **init_kwargs):
         """
         Handles the creation of new subplots when a DynamicMap returns
